yakumo.nova.v2.certificate

Package yakumo :: Package nova :: Package v2 :: Module certificate |
[hide private]
[frames] | no frames]

# Module certificate

source code

Resource class and its manager for root certificates in Compute API v2

Classes | [hide private]
| Resource Resource class for root certificates in Compute API v2
| Manager Manager class for root certificates in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``data``'``,` `'``data``'``,` <yakumo.mapper.NoopClass`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('data', 'data', mapper.Noop), ('private_key', 'private_key', mapper.
      Noop),]